@@ -177,7 +177,7 @@ impl Serialize for ClassMethod {
                 };
                 actual.serialize(serializer)
             }
-            Flavor::Acorn => {
+            Flavor::Acorn { .. } => {
                 let mut s = serializer.serialize_map(None)?;
 
                 {
@@ -344,7 +344,7 @@ impl Serialize for ClassProperty {
                 };
                 actual.serialize(serializer)
             }
-            Flavor::Acorn => {
+            Flavor::Acorn { .. } => {
                 let mut s = serializer.serialize_map(None)?;
 
                 {
