@@ -18,21 +18,28 @@ where
 
 pub(crate) fn skip_expression_for_fn<T>(_: T) -> bool {
     match Flavor::current() {
-        Flavor::Acorn => false,
+        Flavor::Acorn { .. } => false,
         Flavor::Babel => true,
     }
 }
 
 pub(crate) fn skip_interpreter<T>(_: T) -> bool {
     match Flavor::current() {
-        Flavor::Acorn => true,
+        Flavor::Acorn { .. } => true,
         Flavor::Babel => false,
     }
 }
 
 pub(crate) fn skip_typescript<T>(_: T) -> bool {
     match Flavor::current() {
-        Flavor::Acorn => true,
+        Flavor::Acorn { .. } => true,
         Flavor::Babel => false,
     }
 }
+
+pub(crate) fn skip_comments_on_program<T>(_: T) -> bool {
+    match Flavor::current() {
+        Flavor::Acorn { extra_comments } => !extra_comments,
+        _ => true,
+    }
+}
